@@ -67,7 +67,7 @@ def test_get_tiddlers_limited():
     short_recipe = Recipe(name='foobar')
     short_recipe.set_recipe([
         [bagone, ''],
-        [bagfour, '[tag[tagone]]']
+        [bagfour, 'select=tag:tagone']
         ])
     tiddlers = control.get_tiddlers_from_recipe(short_recipe)
     assert len(tiddlers) == 2, 'tiddler list should be length 2, is %s' % len(tiddlers)
@@ -81,7 +81,7 @@ def test_determine_bag_simple():
     This means, which bag does the filter match for.
     """
     bag = control.determine_bag_for_tiddler(recipe, tiddlers[0])
-    assert bag.name == bagthree.name, 'bag name should be bagthree, is %s' % bag.name
+    assert bag.name == bagone.name
 
 def test_determine_bag_filtered():
     """
@@ -90,14 +90,14 @@ def test_determine_bag_filtered():
     short_recipe = Recipe(name='foobar')
     short_recipe.set_recipe([
         [bagone, ''],
-        [bagfour, '[tag[tagone]]']
+        [bagfour, 'select=tag:tagone']
         ])
     bag = control.determine_bag_for_tiddler(short_recipe, tiddlers[0])
     assert bag.name == bagfour.name, 'bag name should be bagfour, is %s' % bag.name
 
     short_recipe.set_recipe([
         [bagone, ''],
-        [bagfour, '[tag[tagthree]]']
+        [bagfour, 'select=tag:tagthree']
         ])
     bag = control.determine_bag_for_tiddler(short_recipe, tiddlers[0])
     assert bag.name == bagone.name, 'bag name should be bagone, is %s' % bag.name
@@ -110,14 +110,14 @@ def test_determine_tiddler_from_recipe():
     short_recipe = Recipe(name='foobar')
     short_recipe.set_recipe([
         [bagone, ''],
-        [bagfour, '[tag[tagone]]']
+        [bagfour, 'select=tag:tagone']
         ])
     bag = control.determine_tiddler_bag_from_recipe(short_recipe, tiddlers[0])
     assert bag.name == bagfour.name, 'bag name should be bagfour, is %s' % bag.name
 
     short_recipe.set_recipe([
         [bagone, ''],
-        [bagfour, '[tag[tagthree]]']
+        [bagfour, 'select=tag:tagthree']
         ])
     bag = control.determine_tiddler_bag_from_recipe(short_recipe, tiddlers[0])
     assert bag.name == bagone.name, 'bag name should be bagone, is %s' % bag.name
@@ -132,7 +132,7 @@ def test_determine_bag_fail():
 
     lonely_recipe = Recipe(name='thing')
     lonely_recipe.set_recipe([
-        [bagone, '[tag[hello]]']
+        [bagone, 'select=tag:hello']
         ])
 
     lonely_tiddler = Tiddler('lonely')
@@ -141,7 +141,7 @@ def test_determine_bag_fail():
     assert bag.name == bagone.name
 
     lonely_recipe.set_recipe([
-        [bagone, '[tag[goodbye]]']
+        [bagone, 'select=tag:goodbye']
         ])
     py.test.raises(NoBagError,
             'bag = control.determine_bag_for_tiddler(lonely_recipe, lonely_tiddler)')
@@ -160,5 +160,3 @@ def test_recipe_policy():
     assert policy_recipe.policy.create == ['c']
     assert policy_recipe.policy.delete == ['d']
     assert policy_recipe.policy.owner == 'e'
-
-
